import { getEndpoint, postEndpoint } from './endpoint.js';
import { DEFAULT_BASE_URL } from './config.js';
export * from './types/safe-info.js';
export * from './types/safe-apps.js';
export * from './types/transactions.js';
export * from './types/chains.js';
export * from './types/common.js';
export * from './types/master-copies.js';
export * from './types/decoded-data.js';
export * from './types/safe-messages.js';
// Can be set externally to a different CGW host
let baseUrl = DEFAULT_BASE_URL;
/**
 * Set the base CGW URL
 */
export const setBaseUrl = (url) => {
    baseUrl = url;
};
/* eslint-disable @typescript-eslint/explicit-module-boundary-types */
/**
 * Get basic information about a Safe. E.g. owners, modules, version etc
 */
export function getSafeInfo(chainId, address) {
    return getEndpoint(baseUrl, '/v1/chains/{chainId}/safes/{address}', {
        path: { chainId, address }
    });
}
/**
 * Get filterable list of incoming transactions
 */
export function getIncomingTransfers(chainId, address, query, pageUrl) {
    return getEndpoint(baseUrl, '/v1/chains/{chainId}/safes/{address}/incoming-transfers/', {
        path: { chainId, address },
        query
    }, pageUrl);
}
/**
 * Get filterable list of module transactions
 */
export function getModuleTransactions(chainId, address, query, pageUrl) {
    return getEndpoint(baseUrl, '/v1/chains/{chainId}/safes/{address}/module-transactions/', {
        path: { chainId, address },
        query
    }, pageUrl);
}
/**
 * Get filterable list of multisig transactions
 */
export function getMultisigTransactions(chainId, address, query, pageUrl) {
    return getEndpoint(baseUrl, '/v1/chains/{chainId}/safes/{address}/multisig-transactions/', {
        path: { chainId, address },
        query
    }, pageUrl);
}
/**
 * Get the total balance and all assets stored in a Safe
 */
export function getBalances(chainId, address, currency = 'usd', query = {}) {
    return getEndpoint(baseUrl, '/v1/chains/{chainId}/safes/{address}/balances/{currency}', {
        path: { chainId, address, currency },
        query
    });
}
/**
 * Get a list of supported fiat currencies (e.g. USD, EUR etc)
 */
export function getFiatCurrencies() {
    return getEndpoint(baseUrl, '/v1/balances/supported-fiat-codes');
}
/**
 * Get the addresses of all Safes belonging to an owner
 */
export function getOwnedSafes(chainId, address) {
    return getEndpoint(baseUrl, '/v1/chains/{chainId}/owners/{address}/safes', {
        path: { chainId, address }
    });
}
/**
 * Get NFTs stored in a Safe
 */
export function getCollectibles(chainId, address, query = {}) {
    return getEndpoint(baseUrl, '/v1/chains/{chainId}/safes/{address}/collectibles', {
        path: { chainId, address },
        query
    });
}
/**
 * Get NFTs stored in a Safe
 */
export function getCollectiblesPage(chainId, address, query = {}, pageUrl) {
    return getEndpoint(baseUrl, '/v2/chains/{chainId}/safes/{address}/collectibles', { path: { chainId, address }, query }, pageUrl);
}
/**
 * Get a list of past Safe transactions
 */
export function getTransactionHistory(chainId, address, pageUrl) {
    return getEndpoint(baseUrl, '/v1/chains/{chainId}/safes/{safe_address}/transactions/history', { path: { chainId, safe_address: address }, query: {} }, pageUrl);
}
/**
 * Get the list of pending transactions
 */
export function getTransactionQueue(chainId, address, pageUrl, trusted) {
    return getEndpoint(baseUrl, '/v1/chains/{chainId}/safes/{safe_address}/transactions/queued', { path: { chainId, safe_address: address }, query: { trusted } }, pageUrl);
}
/**
 * Get the details of an individual transaction by its id
 */
export function getTransactionDetails(chainId, transactionId) {
    return getEndpoint(baseUrl, '/v1/chains/{chainId}/transactions/{transactionId}', {
        path: { chainId, transactionId }
    });
}
/**
 * Request a gas estimate & recommmended tx nonce for a created transaction
 */
export function postSafeGasEstimation(chainId, address, body) {
    return postEndpoint(baseUrl, '/v2/chains/{chainId}/safes/{safe_address}/multisig-transactions/estimations', {
        path: { chainId, safe_address: address },
        body
    });
}
/**
 * Propose a new transaction for other owners to sign/execute
 */
export function proposeTransaction(chainId, address, body) {
    return postEndpoint(baseUrl, '/v1/chains/{chainId}/transactions/{safe_address}/propose', {
        path: { chainId, safe_address: address },
        body
    });
}
/**
 * Returns all defined chain configs
 */
export function getChainsConfig(query) {
    return getEndpoint(baseUrl, '/v1/chains', {
        query
    });
}
/**
 * Returns a chain config
 */
export function getChainConfig(chainId) {
    return getEndpoint(baseUrl, '/v1/chains/{chainId}', {
        path: { chainId: chainId }
    });
}
/**
 * Returns Safe Apps List
 */
export function getSafeApps(chainId, query = {}) {
    return getEndpoint(baseUrl, '/v1/chains/{chainId}/safe-apps', {
        path: { chainId: chainId },
        query
    });
}
/**
 * Returns list of Master Copies
 */
export function getMasterCopies(chainId) {
    return getEndpoint(baseUrl, '/v1/chains/{chainId}/about/master-copies', {
        path: { chainId: chainId }
    });
}
/**
 * Returns decoded data
 */
export function getDecodedData(chainId, encodedData) {
    return postEndpoint(baseUrl, '/v1/chains/{chainId}/data-decoder', {
        path: { chainId: chainId },
        body: { data: encodedData }
    });
}
/**
 * Returns list of `SafeMessage`s
 */
export function getSafeMessages(chainId, address, pageUrl) {
    return getEndpoint(baseUrl, '/v1/chains/{chainId}/safes/{safe_address}/messages', { path: { chainId, safe_address: address }, query: {} }, pageUrl);
}
/**
 * Returns a `SafeMessage`
 */
export function getSafeMessage(chainId, messageHash) {
    return getEndpoint(baseUrl, '/v1/chains/{chainId}/messages/{message_hash}', {
        path: { chainId, message_hash: messageHash }
    });
}
/**
 * Propose a new `SafeMessage` for other owners to sign
 */
export function proposeSafeMessage(chainId, address, body) {
    return postEndpoint(baseUrl, '/v1/chains/{chainId}/safes/{safe_address}/messages', {
        path: { chainId, safe_address: address },
        body
    });
}
/**
 * Add a confirmation to a `SafeMessage`
 */
export function confirmSafeMessage(chainId, messageHash, body) {
    return postEndpoint(baseUrl, '/v1/chains/{chainId}/messages/{message_hash}/signatures', {
        path: { chainId, message_hash: messageHash },
        body
    });
}
/* eslint-enable @typescript-eslint/explicit-module-boundary-types */
//# sourceMappingURL=index.js.map